| RcppQuantuccia-package | R Documentation |
'QuantLib' bindings are provided for R using 'Rcpp' via an updated variant of the header-only 'Quantuccia' project (put together initially by Peter Caspers) offering an essential subset of 'QuantLib' (and now maintained separately for the calendaring subset). See the included file 'AUTHORS' for a full list of contributors to both 'QuantLib' and 'Quantuccia'. Note that this package provided an initial viability proof, current work is done (via approximately quarterly releases tracking 'QuantLib') in the smaller package 'qlcal' which is generally preferred.
The DESCRIPTION file: This package was not yet installed at build time.
Index: This package was not yet installed at build time.
Dirk Eddelbuettel <edd@debian.org>
Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), QuantLib Authors [aut]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.